﻿//Initialise some variables.
var lay = null;
var xytiles = 10;  //10x10 mosaic
var sensitivity = 50; //percent.
var minPeriod = 500;  //millisecs.
var snapFolder = "/sdcard/Watcher";
var maxPics = 10;  //snaps per folder.
var count = 1;  //snap count.
var frontCam = false;
var autoCap = false;
var motion = false;
var isAwake = false;
var tdim = null;
var timer = null;
var timeout = 20000;
var vibrate = true;
var tipDone = false;

//Called when phone application is started.
function OnStart()
{   
	//Are we an HD device?
	if( app.IsTablet() && app.GetModel().indexOf("Nexus") < 0 ) {
		app.Alert( "Sorry, tablets are not fully supported yet. (Please contact SmartphoneRemote@gmail.com if you require a refund)" );
	}
	
    //Fix orientation to landscape since
    //most phone's cameras work this way.   
    app.SetOrientation( "Landscape" );

	//Disable back key.
	app.EnableBackKey( false );

	//Load settings.
	sensitivity = app.LoadNumber( "Sensitivity", 50 ); 
	timeout = app.LoadNumber( "TimeOut", 20000 );
	frontCam = app.LoadBoolean( "FrontCam", false );
	motion = app.LoadBoolean( "Motion", false );
	autoCap = app.LoadBoolean( "AutoCap", false );
	vibrate = app.LoadBoolean( "Vibrate", true );
	maxPics = app.LoadNumber( "MaxPics", 10 );
	
	//Set menus.
	menus = "Settings:Settings.png,Exit:Exit.png";
	app.SetMenu( menus, "/assets/img" );   
    
    //Create SmartWatch object and set callbacks.
    watch = app.CreateSmartWatch();
    watch.SetOnShow( watch_OnShow );
    watch.SetOnHide( watch_OnHide );
    watch.SetOnSwipe( watch_OnSwipe );
	watch.SetOnTouch( watch_OnTouch );
    watch.SetOnStop( watch_OnStop );
    
	//Create the screen layout now if screen is off. 
    if( !app.IsScreenOn() ) 
		CreateLayout();
    
    //Start capture after 1 second.
    //setTimeout( "StartDetection()", 1000 );
	//StartDetection(); 
	//setInterval( "app.GetRotation();", 1000 );
}

//Called when user selects a menu item.
function OnMenu( name )
{        		
    if( name=="Settings" ) {
		ShowSettings();
	}
	else if( name=="Exit" ) {
		watch.StopApp();
		app.Exit( true );   
	}
}

//Called when configuration changes.
function OnConfig() 
{                  
    CreateLayout();
}

//Create the screen layout. 
function CreateLayout() 
{ 
    if ( lay) app.RemoveLayout( lay );

	//Get orientation. 
    //if ( app.GetOrientation ()=="Landscape" ) portrait = false; 
    //else portrait = true;
	portrait = false;

    //Create main layout. 
    if ( portrait ) dir = "Vertical"; else dir = "Horizontal";
    lay = app.CreateLayout( "Linear", dir + ",FillXY,VCenter" );
    lay.SetBackground( "/res/drawable/pattern_carbon", "repeat" );
 
    //Create linear layout on left for camera view.
    layLeft = app.CreateLayout( "Linear" );    
    layLeft.SetPadding( 0.01,0.01,0.01,0.02 );
    layLeft.SetMargins( 0,0, (portrait?0:0.05), (portrait?0.1:0) );
    layLeft.SetBackColor( "#ff181818" );
    lay.AddChild( layLeft ); 
    
    //Create camera preview label.
    txtPrev = app.CreateText( "Camera Preview" );
    txtPrev.SetMargins( 0,0,0,0.01 );
    layLeft.AddChild( txtPrev ); 
    
    //Create camera view control in a frame layout.
    layFrame = app.CreateLayout( "Frame" );    
    if ( portrait ) { cw=0.9; ch=0.4; } else { cw=0.6; ch=0.8; }
    cam = app.CreateCameraView( cw, ch, (frontCam?"front":"") );  
	cam.SetOnReady( cam_OnReady );  
    layFrame.AddChild( cam );  
    layLeft.AddChild( layFrame ); 
    
    //Create vertical layout on right for other stuff.
    if ( !portrait ) dir = "Vertical"; else dir = "Horizontal";
    layRight = app.CreateLayout( "Linear", dir );
    lay.AddChild( layRight );
    
    //Create layout for capture image.
    layCap = app.CreateLayout( "Linear", "Vertical" );
    layCap.SetPadding( 0.01,0.01,0.01,0.02 );
    layCap.SetBackColor( "#ff181818" );
    layRight.AddChild( layCap );

    //Create capture label.
    txtCap = app.CreateText( "Capture" );
    txtCap.SetMargins( 0,0,0,0.01 );
    layCap.AddChild( txtCap ); 
    
    //Create image control for previewing pictures.
    img = app.CreateImage( null, cw/3, ch/3 );  
    img.SetBackColor( "#ff202020" );
    layCap.AddChild( img );      
    
    //Set target image for picture previews.
    cam.SetPreviewImage( img );

    //Create layout for checkboxes. 
    layChk = app.CreateLayout( "Linear", "Vertical,Left" );
    layRight.AddChild ( layChk );
    
	if( cam.GetCameraCount() > 1 )
	{
	 	//Create 'Front Camera' checkbox.
	    chkFront = app.CreateCheckBox( "Front Camera" );
	    chkFront.SetMargins( 0, (portrait?0:0.01), 0, 0 );
	    chkFront.SetOnTouch( chkFront_OnTouch );
		chkFront.SetChecked( frontCam );
	    layChk.AddChild( chkFront ); 
	}
    //Create 'Motion Detect' checkbox.
    chkMotion = app.CreateCheckBox( "Motion Detect" );
    chkMotion.SetMargins( 0, (portrait?0:0.01), 0, 0 );
    chkMotion.SetChecked( motion );
    chkMotion.SetOnTouch( chkMotion_OnTouch );
    layChk.AddChild( chkMotion ); 

    //Create 'Auto Capture' checkbox.
    chkAutoCap = app.CreateCheckBox( "Auto Capture" );
    chkAutoCap.SetMargins( 0, (portrait?0:0.01), 0, 0 );
    chkAutoCap.SetChecked( autoCap );
    chkAutoCap.SetOnTouch( chkAutoCap_OnTouch );
    layChk.AddChild( chkAutoCap ); 
    
    //Add main layout to app.
    app.AddLayout( lay );
}

//Called when camera is ready.
function cam_OnReady()
{    
    //Create an image control over the top of the 
    //camera view with transparency (alpha) and with a
    //fixed internal bitmap the same size as camera view.
    var w = cam.GetImageWidth();
    var h = cam.GetImageHeight();
    img = app.CreateImage( null, cw, ch, "Fix", w, h );  
    img.SetAlpha( 0.3 );  
    layFrame.AddChild( img );        
    
    //Enable 10x10 matrix motion detection and mark
    //motion detections in the image control.
    //cam.MotionMosaic( xytiles, xytiles, (100-sensitivity)/5, minPeriod, img );
    cam.SetOnMotion( OnMotion );
    
    //Create folder for saved pictures and
    //set image size, counters etc.
    app.MakeFolder( snapFolder );
    cam.SetPictureSize( 1024, 768 );

	//Enable auto-capture if required.
	if( autoCap ) chkAutoCap_OnTouch( true, true );
	
	//Enable motion detection if required.
	if( motion ) chkMotion_OnTouch( true, true );
    
    //Start preview.
    cam.StartPreview();
	
	//Start streaming again if watch is starting us.
	if( app.GetOptions()=="SmartWatch" ) 
		cam.Stream( "SmartWatch" );
}

//Handle 'Front Camera' checkbox.
function chkFront_OnTouch( isChecked )
{
    frontCam = isChecked;
	app.SaveBoolean( "FrontCam", frontCam );

	CreateLayout();
    //setTimeout( "StartDetection()", 1000 ); 
	//StartDetection();
}

//Handle 'Motion Detect' checkbox.
function chkMotion_OnTouch( isChecked, noTips )
{
    motion = isChecked;
	app.SaveBoolean( "Motion", motion );

    if( motion )
        cam.MotionMosaic( xytiles, xytiles, (100-sensitivity)/5, minPeriod, img );
    else
        cam.MotionMosaic( 0, 0, 0, 0, null );

    if ( motion && !noTips ) {
       s = "Motion on the camera preview will\ntrigger";
       s += " alerts on your SmartWatch";
       app.ShowPopup( s, "long");
     }
}

//Handle 'Auto Capture' checkbox.
function chkAutoCap_OnTouch( isChecked, noTips )
{
    autoCap = isChecked;
	app.SaveBoolean( "AutoCap", autoCap );
	
	if( autoCap ) cam.AutoCapture( snapFolder, "AutoCap#", maxPics );
	else cam.AutoCapture( null );

    if ( isChecked  && !noTips) {
       s = "Images will automatically be captured\n";
       s += " when motion detection is enabled";
       app.ShowPopup( s );
    }
}

//Called when motion is detected.
//(data contains an array of detection strength 
//values corresponding to each mosaic tile)
function OnMotion( data )
{
    //now done internally: if ( autoCap ) Snap();
    if( !isAwake ) Wake();
    
    //Vibrate watch.
    if( vibrate ) watch.Vibrate( 100, 100, 1 );
}

//Take a picture and store to sdcard.
function Snap()
{
    //Save picture to sdcard.
	var d = new Date();
	var ds = d.getYear().toString().slice(-2) + "-" + d.getMonth() + "-" + d.getDay() + "  " 
		+ d.getHours() + "-" + d.getMinutes() + "-" + d.getSeconds();
    var file = snapFolder+"/" + ds + ".jpg";
    cam.TakePicture( file );
}

//Called when SmartWatch app is shown.
function watch_OnShow()
{
    //Turn screen on and start streaming.
    Wake();
}

//Called when SmartWatch app is hidden.
function watch_OnHide()
{
    //Turn off streaming.
    Sleep();
}

//Called when SmartWatch app is stopped.
function watch_OnStop()
{
    if( app.GetOptions()=="SmartWatch" ) 
		app.Exit( true );
}

//Called when SmartWatch screen is swiped.
function watch_OnSwipe( dir )
{
    if( isAwake ) 
    { 
        //Snap a photo.
        if( dir=="Up" ) {  
            Snap(); 
            cam.Stream( "" );
            watch.ShowMessage( "Photo Taken" );
            setTimeout( "cam.Stream( 'SmartWatch' )", 1000 );
        }
    }
    else Wake();
}

//Handle SmartWatch touch event.
function  watch_OnTouch( dir, x, y )
{
	if( dir="Down" && !isAwake ) Wake();
}

//Turn screen on and start streaming.
function Wake()
{
	if( !tipDone ) { 
		watch.ShowMessage( "Swipe Up to Take Photo" );
		setTimeout( "cam.Stream( 'SmartWatch' )", 3000 );
		tipDone = true;
	}
    else cam.Stream( "SmartWatch" );
    watch.SetScreenState( "On" );
    isAwake = true;
    
    //Dim screen after a while.
    clearTimeout( timer );
    timer = setTimeout( "Dim()", timeout );
}

//Dim the screen.
function Dim()
{
    watch.SetScreenState("Dim");
    isAwake = false;
    
    //Blank screen after a while.
    clearTimeout( timer );
    timer = setTimeout( "Sleep()", 5000 );
}

//Turn screen off and stop streaming.
function Sleep()
{
    watch.SetScreenState("Off");
    cam.Stream( "" );
    isAwake = false;
}


//Show the settings dialog.
function ShowSettings()
{
	//Stop streaming during settings.
	Sleep();
	
	//Create dialog window.
	dlgSet = app.CreateDialog( "Settings" );
	laySet = app.CreateLayout( "linear", "vertical,FillXY" );
	laySet.SetPadding( 0.02, 0, 0.02, 0 );

	//Create main layout.
	layMain = app.CreateLayout( "Linear", "Horizontal" );
	laySet.AddChild( layMain );
	
	//Create left layout.
	laySetLeft = app.CreateLayout( "Linear", "Vertical,Left" );
	layMain.AddChild( laySetLeft );
	
	txtSens = app.CreateText( "Sensitivity:", -1, -1, "" );
	laySetLeft.AddChild( txtSens );
	spSens = app.CreateSpinner( "10,20,30,40,50,60,70,80,90,100", "" );
	spSens.SetSize( 0.2, -1 );
	spSens.SetText( sensitivity );
	laySetLeft.AddChild( spSens );
	
	txtMax = app.CreateText( "Max Photos:", -1, -1, "" );
	laySetLeft.AddChild( txtMax );
	spMax = app.CreateSpinner( "10,50,100,500,1000", "" );
	spMax.SetSize( 0.2, -1 );
	spMax.SetText( maxPics );
	laySetLeft.AddChild( spMax );
	
	//Create right layout.
	laySetRight = app.CreateLayout( "Linear", "Vertical,Left" );
	layMain.AddChild( laySetRight );
	
	txtTime = app.CreateText( "Watch Timeout:", -1, -1, "" );
	laySetRight.AddChild( txtTime );
	spTime = app.CreateSpinner( "5,10,15,20,30,40,60", "" );
	spTime.SetSize( 0.2, -1 );
	spTime.SetText( timeout/1000 );
	laySetRight.AddChild( spTime );
	
	chkVibrate = app.CreateCheckBox("Vibrate Watch");
	chkVibrate.SetChecked( vibrate );
	laySetRight.AddChild( chkVibrate );

	//Create OK and Cancel buttons.
	laySet2 = app.CreateLayout( "linear", "horizontal,center" );
	laySet2.SetMargins( 0, 0.02, 0, 0.01 );  
	btnSetOK = app.CreateButton( "OK", 0.2, -1, "" );
	btnSetOK.SetOnTouch( btnSetOK_OnTouch );
	laySet2.AddChild( btnSetOK );
	btnSetCancel = app.CreateButton( "Cancel", 0.2, -1, "" );
	btnSetCancel.SetOnTouch( btnSetCancel_OnTouch );
	laySet2.AddChild( btnSetCancel );
	laySet.AddChild( laySet2 );

	//Add dialog layout and show dialog.
	dlgSet.AddLayout( laySet );
	dlgSet.Show();
}

//Handle settings 'OK' click.
function btnSetOK_OnTouch()
{
	//Save settings.
	sensitivity = parseInt(spSens.GetText());
	app.SaveNumber( "Sensitivity", sensitivity ); 
	
	timeout = parseInt(spTime.GetText()) * 1000;
	app.SaveNumber( "TimeOut", timeout ); 
	
	vibrate = chkVibrate.GetChecked();
	app.SaveBoolean( "Vibrate", vibrate );
	
	maxPics = parseInt(spMax.GetText());
	app.SaveNumber( "MaxPics", maxPics ); 
	if( autoCap ) cam.AutoCapture( snapFolder, "AutoCap#", maxPics );
	
	//Remove dialog and wake up camera.
	dlgSet.Dismiss();
	Wake();
}

//Handle settings 'Cancel' click.
function btnSetCancel_OnTouch()
{
	//Remove dialog and wake up camera.
	dlgSet.Dismiss();
	Wake();
}





